from setuptools import setup
setup(
    name='pkg5',
    version='0.1.0',
    description='A example Python package',
    url='https://github.com/el-0mbre',
    author='Stanislav Efimtsev',
    author_email='evendot@yandex.ru',
    license='BSD 2-clause',
    packages=['pkg5'],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.5',
    ],
) 